CorrectnessError

Enum CorrectnessError 

pub enum CorrectnessError {
Show 16 variants PredicateViolation { message: String, }, EmptyString { param: String, }, WhitespaceString { param: String, }, NonAsciiString { param: String, value: String, }, MissingSubstring { param: String, pattern: String, value: String, }, EqualityMismatch { lhs_param: String, rhs_param: String, lhs: String, rhs: String, type_name: &'static str, }, NotPositive { param: String, value: String, type_name: &'static str, }, NegativeValue { param: String, value: String, type_name: &'static str, }, InvalidValue { param: String, value: String, type_name: &'static str, }, OutOfRange { param: String, min: String, max: String, value: String, type_name: &'static str, }, CollectionNotEmpty { param: String, collection_kind: &'static str, type_repr: String, }, CollectionEmpty { param: String, collection_kind: &'static str, type_repr: String, }, KeyPresent { key_name: String, map_name: String, key: String, map_type_repr: String, }, KeyMissing { key_name: String, map_name: String, key: String, map_type_repr: String, }, MemberPresent { member_name: String, set_name: String, set_type_repr: String, }, MemberMissing { member_name: String, set_name: String, set_type_repr: String, },
}
Error type for correctness checks.

Variants



PredicateViolation

A predicate or invariant check failed.

Fields

message: String

The failure message.



EmptyString

A string was empty.

Fields

param: String

The parameter name.



WhitespaceString

A string was all whitespace.

Fields

param: String

The parameter name.



NonAsciiString

A string contained a non-ASCII character.

Fields

param: String

The parameter name.

value: String

The provided value.



MissingSubstring

A string did not contain an expected pattern.

Fields

param: String

The parameter name.

pattern: String

The expected substring.

value: String

The provided value.



EqualityMismatch

Two values were not equal.

Fields

lhs_param: String

The left parameter name.

rhs_param: String

The right parameter name.

lhs: String

The left value.

rhs: String

The right value.

type_name: &'static str

The displayed type name.



NotPositive

A value that must be positive was not positive.

Fields

param: String

The parameter name.

value: String

The provided value.

type_name: &'static str

The displayed type name.



NegativeValue

A value that must not be negative was negative.

Fields

param: String

The parameter name.

value: String

The provided value.

type_name: &'static str

The displayed type name.



InvalidValue

A value was invalid for its type.

Fields

param: String

The parameter name.

value: String

The provided value.

type_name: &'static str

The displayed type name.



OutOfRange

A value was outside an inclusive range.

Fields

param: String

The parameter name.

min: String

The lower bound.

max: String

The upper bound.

value: String

The provided value.

type_name: &'static str

The displayed type name.



CollectionNotEmpty

A collection that must be empty was not empty.

Fields

param: String

The parameter name.

collection_kind: &'static str

The collection kind.

type_repr: String

The collection type representation.



CollectionEmpty

A collection that must not be empty was empty.

Fields

param: String

The parameter name.

collection_kind: &'static str

The collection kind.

type_repr: String

The collection type representation.



KeyPresent

A map key was already present.

Fields

key_name: String

The key parameter name.

map_name: String

The map parameter name.

key: String

The key value.

map_type_repr: String

The map type representation.



KeyMissing

A map key was missing.

Fields

key_name: String

The key parameter name.

map_name: String

The map parameter name.

key: String

The key value.

map_type_repr: String

The map type representation.



MemberPresent

A set member was already present.

Fields

member_name: String

The member parameter name.

set_name: String

The set parameter name.

set_type_repr: String

The set type representation.



MemberMissing

A set member was missing.

Fields

member_name: String

The member parameter name.

set_name: String

The set parameter name.

set_type_repr: String

The set type representation.