pub enum CorrectnessError {
Show 16 variants
PredicateViolation {
message: String,
},
EmptyString {
param: String,
},
WhitespaceString {
param: String,
},
NonAsciiString {
param: String,
value: String,
},
MissingSubstring {
param: String,
pattern: String,
value: String,
},
EqualityMismatch {
lhs_param: String,
rhs_param: String,
lhs: String,
rhs: String,
type_name: &'static str,
},
NotPositive {
param: String,
value: String,
type_name: &'static str,
},
NegativeValue {
param: String,
value: String,
type_name: &'static str,
},
InvalidValue {
param: String,
value: String,
type_name: &'static str,
},
OutOfRange {
param: String,
min: String,
max: String,
value: String,
type_name: &'static str,
},
CollectionNotEmpty {
param: String,
collection_kind: &'static str,
type_repr: String,
},
CollectionEmpty {
param: String,
collection_kind: &'static str,
type_repr: String,
},
KeyPresent {
key_name: String,
map_name: String,
key: String,
map_type_repr: String,
},
KeyMissing {
key_name: String,
map_name: String,
key: String,
map_type_repr: String,
},
MemberPresent {
member_name: String,
set_name: String,
set_type_repr: String,
},
MemberMissing {
member_name: String,
set_name: String,
set_type_repr: String,
},
}Expand description
Error type for correctness checks.
Variants
PredicateViolation
A predicate or invariant check failed.
EmptyString
A string was empty.
WhitespaceString
A string was all whitespace.
NonAsciiString
A string contained a non-ASCII character.
MissingSubstring
A string did not contain an expected pattern.
Fields
EqualityMismatch
Two values were not equal.
Fields
NotPositive
A value that must be positive was not positive.
Fields
NegativeValue
A value that must not be negative was negative.
Fields
InvalidValue
A value was invalid for its type.
Fields
OutOfRange
A value was outside an inclusive range.
Fields
CollectionNotEmpty
A collection that must be empty was not empty.
Fields
CollectionEmpty
A collection that must not be empty was empty.
Fields
KeyPresent
A map key was already present.
Fields
KeyMissing
A map key was missing.
Fields
MemberPresent
A set member was already present.
Fields
MemberMissing
A set member was missing.